
void GEFDetectorConstruction::BuildTrees()
{
	if( !rootFile ) {
		char rootName[100];
		strcpy( rootName, outputDir.c_str() );
		if( outputDir.substr( outputDir.length(), 1 ) == "/" )
			sprintf( rootName, "%sGEF_OUTPUT_%d.root",
					 outputDir.c_str(), seed );
		else
			sprintf( rootName, "%s/GEF_OUTPUT_%d.root",
					 outputDir.c_str(), seed );
		
		rootFile = new TFile( rootName, "RECREATE", "GEF_Simulation" );
	}
	
	char treeName[100];
	strcpy( treeName, "GEF_Simulation_" );
	strcat( treeName, detName.c_str() );
	
	if( macroFile != "none" ) {
		ifstream inFile;
		inFile.open( macroFile, ifstream::in );
		int length;
		inFile.seekg( 0, std::ios::end );
		length = inFile.tellg();
		inFile.seekg( 0, std::ios::beg );
		inFile.close();
		
		inputMacro = macroFile;
	}
	
	if( !input )
		input = new GEFInput();

	if( !inputTree ) {
		char inputTreeName[100];
		strcpy( inputTreeName, treeName );
		strcat( inputTreeName, "_Input" );
		inputTree = new TTree( "GEF_Simulation_Input", inputTreeName );
		inputTree->Branch( "GEFInput", "GEFInput", &input, 32000, 1 );
		
		TString theMacro;
		TString theName;
		TString theOutputDir;
		TString theMaterial;
		TString theShape;
		TString theActMaterial;
		TString theActShape;
		
		theMacro = inputMacro;
		theName = detName;
		theOutputDir = outputDir;

		input->BuildLeaves( (Int_t)(numComponents+1) );
		input->SetInputMacro( theMacro );
		input->SetName( theName );
		input->SetOutputDir( theOutputDir );
		input->SetSourceActivity( (Int_t)totalActivity );
		for( G4int i=0; i<numComponents; i++ ) {
			theName = component[i]->GetName();
			theMaterial = component[i]->GetMaterial()->GetName();
			theShape = component[i]->GetShape();
			theActMaterial = component[i]->GetActMaterial()->GetName();
			theActShape = component[i]->GetActShape();
		
			input->SetCompName( (Int_t)i, theName );
			input->SetCompMaterial( (Int_t)i, theMaterial );
			input->SetCompShape( (Int_t)i, theShape );
			input->SetCompBox( (Int_t)i,
							   (Double_t)(component[i]->GetBoxDim().x()),
							   (Double_t)(component[i]->GetBoxDim().y()),
							   (Double_t)(component[i]->GetBoxDim().z()) );
			input->SetCompCylHeight( (Int_t)i,
									 (Double_t)(component[i]->GetCylHeight()) );
			input->SetCompCylRadius( (Int_t)i,
									 (Double_t)(component[i]->GetCylRadius()) );
			input->SetCompPos( (Int_t)i,
							   (Double_t)(component[i]->GetPosition().x()),
							   (Double_t)(component[i]->GetPosition().y()),
							   (Double_t)(component[i]->GetPosition().z()) );
			input->SetCompRot( (Int_t)i,
							   (Double_t)(component[i]->GetRotation().x()),
							   (Double_t)(component[i]->GetRotation().y()),
							   (Double_t)(component[i]->GetRotation().z()) );
			input->SetActMaterial( (Int_t)i, theActMaterial );
			input->SetActShape( (Int_t)i, theActShape );
			input->SetActBox( (Int_t)i, 
							  (Double_t)(component[i]->GetActBoxDim().x()),
							  (Double_t)(component[i]->GetActBoxDim().y()),
							  (Double_t)(component[i]->GetActBoxDim().z()) );
			input->SetActCylHeight((Int_t)i,
								   (Double_t)(component[i]->GetActCylHeight()));
			input->SetActCylRadius((Int_t)i,
								   (Double_t)(component[i]->GetActCylRadius()));
			input->SetActPos( (Int_t)i,
							  (Double_t)(component[i]->GetActPosition().x()),
							  (Double_t)(component[i]->GetActPosition().y()),
							  (Double_t)(component[i]->GetActPosition().z()) );
			input->SetActRot( (Int_t)i,
							  (Double_t)(component[i]->GetActRotation().x()),
							  (Double_t)(component[i]->GetActRotation().y()),
							  (Double_t)(component[i]->GetActRotation().z()) );
		}
		
		inputTree->Fill();
	}
	
	if( !output )
		output = new GEFOutput();
	
	if( !outputTree ) {
		char outputTreeName[100];
		strcpy( outputTreeName, treeName );
		strcat( outputTreeName, "_Output" );
		outputTree = new TTree( "GEF_Simulation_Output", outputTreeName );
		outputTree->Branch( "GEFOutput", "GEFOutput", &output, 32000, 1 );
	}
}

