#ifndef GEFInput_h
#define GEFInput_h 1

//	ROOT includes
#include "TObject.h"
#include "TString.h"

class GEFInput : public TObject
{

	private:
		TString		inputMacro;
		TString		name;
		TString		outputDir;
		Int_t		numComponents;
		Double_t	sourceActivity;
		Int_t		numDecays;
		TString	   *compName;			//[numComponents]
		TString	   *compMaterial;		//[numComponents]
		TString	   *compShape;			//[numComponents]
		Double_t   *compBoxX;			//[numComponents]
		Double_t   *compBoxY;			//[numComponents]
		Double_t   *compBoxZ;			//[numComponents]
		Double_t   *compCylHeight;		//[numComponents]
		Double_t   *compCylRadius;		//[numComponents]
		Double_t   *compPosX;			//[numComponents]
		Double_t   *compPosY;			//[numComponents]
		Double_t   *compPosZ;			//[numComponents]
		Double_t   *compRotX;			//[numComponents]
		Double_t   *compRotY;			//[numComponents]
		Double_t   *compRotZ;			//[numComponents]
		TString	   *actMaterial;		//[numComponents]
		TString	   *actShape;			//[numComponents]
		Double_t   *actBoxX;			//[numComponents]
		Double_t   *actBoxY;			//[numComponents]
		Double_t   *actBoxZ;			//[numComponents]
		Double_t   *actCylHeight;		//[numComponents]
		Double_t   *actCylRadius;		//[numComponents]
		Double_t   *actPosX;			//[numComponents]
		Double_t   *actPosY;			//[numComponents]
		Double_t   *actPosZ;			//[numComponents]
		Double_t   *actRotX;			//[numComponents]
		Double_t   *actRotY;			//[numComponents]
		Double_t   *actRotZ;			//[numComponents]
		
	public:
		GEFInput();
		~GEFInput();

	public:
		void BuildLeaves( Int_t );
		void ClearLeaves();
	
		inline void SetInputMacro( TString iM ) { inputMacro = iM; };
		inline void SetName( TString na ) { name = na; };
		inline void SetOutputDir( TString oD ) { outputDir = oD; };
		inline void SetSourceActivity( Double_t act ) { sourceActivity = act; };
		inline void SetNumDecays( Int_t num ) { numDecays = num; };

		inline void SetCompName( Int_t i, TString na )
				{ compName[i] = na; };
		inline void	SetCompMaterial( Int_t i, TString mat )
				{ compMaterial[i] = mat; };
		inline void SetCompShape( Int_t i, TString sh )
				{ compShape[i] = sh; };
		inline void SetCompBox( Int_t i, Double_t x, Double_t y, Double_t z )
				{ compBoxX[i] = x;
				  compBoxY[i] = y;
				  compBoxZ[i] = z; }
		inline void SetCompCylHeight( Int_t i, Double_t height )
				{ compCylHeight[i] = height; };
		inline void SetCompCylRadius( Int_t i, Double_t radius )
				{ compCylRadius[i] = radius; };
		inline void SetCompPos( Int_t i, Double_t x, Double_t y, Double_t z  )
				{ compPosX[i] = x;
				  compPosY[i] = y;
				  compPosZ[i] = z; }
		inline void SetCompRot( Int_t i, Double_t x, Double_t y, Double_t z  )
				{ compRotX[i] = x;
				  compRotY[i] = y;
				  compRotZ[i] = z; }

		inline void SetActMaterial( Int_t i, TString mat )
				{ actMaterial[i] = mat; };
		inline void SetActShape( Int_t i, TString sh )
				{ actShape[i] = sh; };
		inline void SetActBox( Int_t i, Double_t x, Double_t y, Double_t z  )
				{ actBoxX[i] = x;
				  actBoxY[i] = y;
				  actBoxZ[i] = z; }
		inline void SetActCylHeight( Int_t i, Double_t height )
				{ actCylHeight[i] = height; };
		inline void SetActCylRadius( Int_t i, Double_t radius )
				{ actCylRadius[i] = radius; };
		inline void SetActPos( Int_t i, Double_t x, Double_t y, Double_t z  )
				{ actPosX[i] = x;
				  actPosY[i] = y;
				  actPosZ[i] = z; }
		inline void SetActRot( Int_t i, Double_t x, Double_t y, Double_t z  )
				{ actRotX[i] = x;
				  actRotY[i] = y;
				  actRotZ[i] = z; }
				  
		ClassDef( GEFInput, 1 )
};

#endif
