#ifndef GEFOutput_h
#define GEFOutput_h 1

//	ROOT includes
#include "TObject.h"
#include "TString.h"

class GEFOutput : public TObject
{

	private:
		Int_t			event;
		Int_t			numParticles;
		Double_t		eventTime;
		TString	   *particle;			//[numParticles]
		Double_t	   *energy;				//[numParticles]
		Double_t	   *depTime;			//[numParticles]
		TString	   *volume;				//[numParticles]
		Double_t	   *volumeLocX;			//[numParticles]
		Double_t	   *volumeLocY;			//[numParticles]
		Double_t	   *volumeLocZ;			//[numParticles]
		Double_t	   *worldLocX;			//[numParticles]
		Double_t	   *worldLocY;			//[numParticles]
		Double_t	   *worldLocZ;			//[numParticles]
		TString	   *preProc;			//[numParticles]
		TString	   *postProc;			//[numParticles]
		Int_t		   *trackID;			//[numParticles]
		Int_t		   *parentID;			//[numParticles]
		TString	   *creationProc;		//[numParticles]
		Double_t	   *creationLocX;		//[numParticles]
		Double_t	   *creationLocY;		//[numParticles]
		Double_t	   *creationLocZ;		//[numParticles]

	public:
		GEFOutput();
		~GEFOutput();

	public:
		void BuildLeaves( Int_t );
		void ClearLeaves();
	
		inline void SetEvent( Int_t ev ) { event = ev; };
		inline void SetEventTime( Double_t ti ) { eventTime = ti; };
		inline void SetParticle( Int_t i, TString part )
				{ particle[i] = part; };
		inline void SetEnergy( Int_t i, Double_t en ) { energy[i] = en; };
		inline void SetDepTime( Int_t i, Double_t dt ) { depTime[i] = dt; };
		inline void SetVolume( Int_t i, TString vol) { volume[i] = vol; };
		inline void SetVolumeLoc( Int_t i, Double_t x, Double_t y, Double_t z )
				{ volumeLocX[i] = x;
				  volumeLocY[i] = y;
				  volumeLocZ[i] = z; };
		inline void SetWorldLoc( Int_t i, Double_t x, Double_t y, Double_t z )
				{ worldLocX[i] = x;
				  worldLocY[i] = y;
				  worldLocZ[i] = z; };
		inline void SetPreProc( Int_t i, TString proc )
				{ preProc[i] = proc; };
		inline void SetPostProc( Int_t i, TString proc )
				{ postProc[i] = proc; };
		inline void SetTrackID( Int_t i, Int_t id ) { trackID[i] = id; };
		inline void SetParentID( Int_t i, Int_t id ) { parentID[i] = id; };
		inline void SetCreationProc( Int_t i, TString proc )
				{ creationProc[i] = proc; };
		inline void SetCreationLoc( Int_t i, Double_t x, Double_t y, Double_t z)
				{ creationLocX[i] = x;
				  creationLocY[i] = y;
				  creationLocZ[i] = z; };
		
		ClassDef( GEFOutput, 1 )
};

#endif
